-------------------------------------------------------------------
-- System Generator version 11.1.00 VHDL source file.
--
-- Copyright(C) 2008 by Xilinx, Inc.  All rights reserved.  This
-- text/file contains proprietary, confidential information of Xilinx,
-- Inc., is distributed under license from Xilinx, Inc., and may be used,
-- copied and/or disclosed only pursuant to the terms of a valid license
-- agreement with Xilinx, Inc.  Xilinx hereby grants you a license to use
-- this text/file solely for design, simulation, implementation and
-- creation of design files limited to Xilinx devices or technologies.
-- Use with non-Xilinx devices or technologies is expressly prohibited
-- and immediately terminates your license unless covered by a separate
-- agreement.
--
-- Xilinx is providing this design, code, or information "as is" solely
-- for use in developing programs and solutions for Xilinx devices.  By
-- providing this design, code, or information as one possible
-- implementation of this feature, application or standard, Xilinx is
-- making no representation that this implementation is free from any
-- claims of infringement.  You are responsible for obtaining any rights
-- you may require for your implementation.  Xilinx expressly disclaims
-- any warranty whatsoever with respect to the adequacy of the
-- implementation, including but not limited to warranties of
-- merchantability or fitness for a particular purpose.
--
-- Xilinx products are not intended for use in life support appliances,
-- devices, or systems.  Use in such applications is expressly prohibited.
--
-- Any modifications that are made to the source code are done at the user's
-- sole risk and will be unsupported.
--
-- This copyright and support notice must be retained as part of this
-- text at all times.  (c) Copyright 1995-2007 Xilinx, Inc.  All rights
-- reserved.
-------------------------------------------------------------------
library IEEE;
use IEEE.std_logic_1164.all;

entity plbaddrpref is
    generic (
        C_BASEADDR : std_logic_vector(31 downto 0) := X"80000000";
        C_HIGHADDR : std_logic_vector(31 downto 0) := X"8000FFFF";
        C_SPLB_DWIDTH         : integer range 32 to 128   := 32;
        C_SPLB_NATIVE_DWIDTH  : integer range 32 to 32    := 32
    );
    port (
        addrpref           : out std_logic_vector(10-1 downto 0);
        sl_rddbus          : out std_logic_vector(0 to C_SPLB_DWIDTH-1);
        plb_wrdbus         : in  std_logic_vector(0 to C_SPLB_DWIDTH-1);
        sgsl_rddbus        : in  std_logic_vector(0 to C_SPLB_NATIVE_DWIDTH-1);
        sgplb_wrdbus       : out std_logic_vector(0 to C_SPLB_NATIVE_DWIDTH-1)
    );
end plbaddrpref;

architecture behavior of plbaddrpref is

signal sl_rddbus_i            : std_logic_vector(0 to C_SPLB_DWIDTH-1);

begin
    addrpref <= C_BASEADDR(32-1 downto 22);

-------------------------------------------------------------------------------
-- Mux/Steer data/be's correctly for connect 32-bit slave to 128-bit plb
-------------------------------------------------------------------------------
GEN_128_TO_32_SLAVE : if C_SPLB_NATIVE_DWIDTH = 32 and C_SPLB_DWIDTH = 128 generate
begin
    -----------------------------------------------------------------------
    -- Map lower rd data to each quarter of the plb slave read bus
    -----------------------------------------------------------------------
    sl_rddbus_i(0 to 31)      <=  sgsl_rddbus(0 to C_SPLB_NATIVE_DWIDTH-1);
    sl_rddbus_i(32 to 63)     <=  sgsl_rddbus(0 to C_SPLB_NATIVE_DWIDTH-1);
    sl_rddbus_i(64 to 95)     <=  sgsl_rddbus(0 to C_SPLB_NATIVE_DWIDTH-1);
    sl_rddbus_i(96 to 127)    <=  sgsl_rddbus(0 to C_SPLB_NATIVE_DWIDTH-1);
end generate GEN_128_TO_32_SLAVE;

-------------------------------------------------------------------------------
-- Mux/Steer data/be's correctly for connect 32-bit slave to 64-bit plb
-------------------------------------------------------------------------------
GEN_64_TO_32_SLAVE : if C_SPLB_NATIVE_DWIDTH = 32 and C_SPLB_DWIDTH = 64 generate
begin
    ---------------------------------------------------------------------------        
    -- Map lower rd data to upper and lower halves of plb slave read bus
    ---------------------------------------------------------------------------        
    sl_rddbus_i(0 to 31)      <=  sgsl_rddbus(0 to C_SPLB_NATIVE_DWIDTH-1);
    sl_rddbus_i(32 to 63)     <=  sgsl_rddbus(0 to C_SPLB_NATIVE_DWIDTH-1);
end generate GEN_64_TO_32_SLAVE;

-------------------------------------------------------------------------------
-- IPIF DWidth = PLB DWidth
-- If IPIF Slave Data width is equal to the PLB Bus Data Width
-- Then BE and Read Data Bus map directly to eachother.
-------------------------------------------------------------------------------
GEN_FOR_EQUAL_SLAVE : if C_SPLB_NATIVE_DWIDTH = C_SPLB_DWIDTH generate
    sl_rddbus_i    <= sgsl_rddbus;
end generate GEN_FOR_EQUAL_SLAVE;

    sl_rddbus       <= sl_rddbus_i;
    sgplb_wrdbus    <= plb_wrdbus(0 to C_SPLB_NATIVE_DWIDTH-1);

end behavior;
library IEEE;
use IEEE.std_logic_1164.all;
use work.conv_pkg.all;

entity w3_warplab_buffers_plbw is
  generic (
    C_BASEADDR: std_logic_vector(31 downto 0) := X"80000000";
    C_HIGHADDR: std_logic_vector(31 downto 0) := X"80000FFF";
    C_SPLB_AWIDTH: integer := 0;
    C_SPLB_DWIDTH: integer := 0;
    C_SPLB_MID_WIDTH: integer := 0;
    C_SPLB_NATIVE_DWIDTH: integer := 0;
    C_SPLB_NUM_MASTERS: integer := 0;
    C_SPLB_SUPPORT_BURSTS: integer := 0
  );
  port (
    agc_done: in std_logic; 
    fromagc_radio1_i: in std_logic_vector(0 to 11); 
    fromagc_radio1_q: in std_logic_vector(0 to 11); 
    fromagc_radio2_i: in std_logic_vector(0 to 11); 
    fromagc_radio2_q: in std_logic_vector(0 to 11); 
    fromagc_radio3_i: in std_logic_vector(0 to 11); 
    fromagc_radio3_q: in std_logic_vector(0 to 11); 
    fromagc_radio4_i: in std_logic_vector(0 to 11); 
    fromagc_radio4_q: in std_logic_vector(0 to 11); 
    plb_abus: in std_logic_vector(0 to 31); 
    plb_pavalid: in std_logic; 
    plb_rnw: in std_logic; 
    plb_wrdbus: in std_logic_vector(0 to C_SPLB_DWIDTH-1); 
    radio1_adc_i: in std_logic_vector(0 to 11); 
    radio1_adc_q: in std_logic_vector(0 to 11); 
    radio1_rssi: in std_logic_vector(0 to 9); 
    radio2_adc_i: in std_logic_vector(0 to 11); 
    radio2_adc_q: in std_logic_vector(0 to 11); 
    radio2_rssi: in std_logic_vector(0 to 9); 
    radio3_adc_i: in std_logic_vector(0 to 11); 
    radio3_adc_q: in std_logic_vector(0 to 11); 
    radio3_rssi: in std_logic_vector(0 to 9); 
    radio4_adc_i: in std_logic_vector(0 to 11); 
    radio4_adc_q: in std_logic_vector(0 to 11); 
    radio4_rssi: in std_logic_vector(0 to 9); 
    splb_clk: in std_logic; 
    splb_rst: in std_logic; 
    startcapture: in std_logic; 
    starttx: in std_logic; 
    stoptx: in std_logic; 
    sysgen_clk: in std_logic; 
    debug_agc_done: out std_logic; 
    debug_capturing: out std_logic; 
    debug_transmitting: out std_logic; 
    radio1_dac_i: out std_logic_vector(0 to 11); 
    radio1_dac_q: out std_logic_vector(0 to 11); 
    radio2_dac_i: out std_logic_vector(0 to 11); 
    radio2_dac_q: out std_logic_vector(0 to 11); 
    radio3_dac_i: out std_logic_vector(0 to 11); 
    radio3_dac_q: out std_logic_vector(0 to 11); 
    radio4_dac_i: out std_logic_vector(0 to 11); 
    radio4_dac_q: out std_logic_vector(0 to 11); 
    rssi_adc_clk: out std_logic; 
    sl_addrack: out std_logic; 
    sl_rdcomp: out std_logic; 
    sl_rddack: out std_logic; 
    sl_rddbus: out std_logic_vector(0 to C_SPLB_DWIDTH-1); 
    sl_wait: out std_logic; 
    sl_wrcomp: out std_logic; 
    sl_wrdack: out std_logic
  );
end w3_warplab_buffers_plbw;

architecture structural of w3_warplab_buffers_plbw is
  signal agc_done_x0: std_logic;
  signal clk: std_logic;
  signal debug_agc_done_x0: std_logic;
  signal debug_capturing_x0: std_logic;
  signal debug_transmitting_x0: std_logic;
  signal fromagc_radio1_i_x0: std_logic_vector(11 downto 0);
  signal fromagc_radio1_q_x0: std_logic_vector(11 downto 0);
  signal fromagc_radio2_i_x0: std_logic_vector(11 downto 0);
  signal fromagc_radio2_q_x0: std_logic_vector(11 downto 0);
  signal fromagc_radio3_i_x0: std_logic_vector(11 downto 0);
  signal fromagc_radio3_q_x0: std_logic_vector(11 downto 0);
  signal fromagc_radio4_i_x0: std_logic_vector(11 downto 0);
  signal fromagc_radio4_q_x0: std_logic_vector(11 downto 0);
  signal plb_abus_x0: std_logic_vector(31 downto 0);
  signal plb_pavalid_x0: std_logic;
  signal plb_rnw_x0: std_logic;
  signal plbaddrpref_addrpref_net: std_logic_vector(9 downto 0);
  signal plbaddrpref_plb_wrdbus_net: std_logic_vector(C_SPLB_DWIDTH-1 downto 0);
  signal plbaddrpref_sgplb_wrdbus_net: std_logic_vector(31 downto 0);
  signal plbaddrpref_sgsl_rddbus_net: std_logic_vector(31 downto 0);
  signal plbaddrpref_sl_rddbus_net: std_logic_vector(C_SPLB_DWIDTH-1 downto 0);
  signal radio1_adc_i_x0: std_logic_vector(11 downto 0);
  signal radio1_adc_q_x0: std_logic_vector(11 downto 0);
  signal radio1_dac_i_x0: std_logic_vector(11 downto 0);
  signal radio1_dac_q_x0: std_logic_vector(11 downto 0);
  signal radio1_rssi_x0: std_logic_vector(9 downto 0);
  signal radio2_adc_i_x0: std_logic_vector(11 downto 0);
  signal radio2_adc_q_x0: std_logic_vector(11 downto 0);
  signal radio2_dac_i_x0: std_logic_vector(11 downto 0);
  signal radio2_dac_q_x0: std_logic_vector(11 downto 0);
  signal radio2_rssi_x0: std_logic_vector(9 downto 0);
  signal radio3_adc_i_x0: std_logic_vector(11 downto 0);
  signal radio3_adc_q_x0: std_logic_vector(11 downto 0);
  signal radio3_dac_i_x0: std_logic_vector(11 downto 0);
  signal radio3_dac_q_x0: std_logic_vector(11 downto 0);
  signal radio3_rssi_x0: std_logic_vector(9 downto 0);
  signal radio4_adc_i_x0: std_logic_vector(11 downto 0);
  signal radio4_adc_q_x0: std_logic_vector(11 downto 0);
  signal radio4_dac_i_x0: std_logic_vector(11 downto 0);
  signal radio4_dac_q_x0: std_logic_vector(11 downto 0);
  signal radio4_rssi_x0: std_logic_vector(9 downto 0);
  signal rssi_adc_clk_x0: std_logic;
  signal sl_addrack_x0: std_logic;
  signal sl_rdcomp_x0: std_logic;
  signal sl_rddack_x0: std_logic;
  signal sl_wait_x0: std_logic;
  signal sl_wrcomp_x0: std_logic;
  signal sl_wrdack_x0: std_logic;
  signal splb_rst_x0: std_logic;
  signal startcapture_x0: std_logic;
  signal starttx_x0: std_logic;
  signal stoptx_x0: std_logic;
  signal xps_clk: std_logic;

begin
  agc_done_x0 <= agc_done;
  fromagc_radio1_i_x0 <= fromagc_radio1_i;
  fromagc_radio1_q_x0 <= fromagc_radio1_q;
  fromagc_radio2_i_x0 <= fromagc_radio2_i;
  fromagc_radio2_q_x0 <= fromagc_radio2_q;
  fromagc_radio3_i_x0 <= fromagc_radio3_i;
  fromagc_radio3_q_x0 <= fromagc_radio3_q;
  fromagc_radio4_i_x0 <= fromagc_radio4_i;
  fromagc_radio4_q_x0 <= fromagc_radio4_q;
  plb_abus_x0 <= plb_abus;
  plb_pavalid_x0 <= plb_pavalid;
  plb_rnw_x0 <= plb_rnw;
  plbaddrpref_plb_wrdbus_net <= plb_wrdbus;
  radio1_adc_i_x0 <= radio1_adc_i;
  radio1_adc_q_x0 <= radio1_adc_q;
  radio1_rssi_x0 <= radio1_rssi;
  radio2_adc_i_x0 <= radio2_adc_i;
  radio2_adc_q_x0 <= radio2_adc_q;
  radio2_rssi_x0 <= radio2_rssi;
  radio3_adc_i_x0 <= radio3_adc_i;
  radio3_adc_q_x0 <= radio3_adc_q;
  radio3_rssi_x0 <= radio3_rssi;
  radio4_adc_i_x0 <= radio4_adc_i;
  radio4_adc_q_x0 <= radio4_adc_q;
  radio4_rssi_x0 <= radio4_rssi;
  xps_clk <= splb_clk;
  splb_rst_x0 <= splb_rst;
  startcapture_x0 <= startcapture;
  starttx_x0 <= starttx;
  stoptx_x0 <= stoptx;
  clk <= sysgen_clk;
  debug_agc_done <= debug_agc_done_x0;
  debug_capturing <= debug_capturing_x0;
  debug_transmitting <= debug_transmitting_x0;
  radio1_dac_i <= radio1_dac_i_x0;
  radio1_dac_q <= radio1_dac_q_x0;
  radio2_dac_i <= radio2_dac_i_x0;
  radio2_dac_q <= radio2_dac_q_x0;
  radio3_dac_i <= radio3_dac_i_x0;
  radio3_dac_q <= radio3_dac_q_x0;
  radio4_dac_i <= radio4_dac_i_x0;
  radio4_dac_q <= radio4_dac_q_x0;
  rssi_adc_clk <= rssi_adc_clk_x0;
  sl_addrack <= sl_addrack_x0;
  sl_rdcomp <= sl_rdcomp_x0;
  sl_rddack <= sl_rddack_x0;
  sl_rddbus <= plbaddrpref_sl_rddbus_net;
  sl_wait <= sl_wait_x0;
  sl_wrcomp <= sl_wrcomp_x0;
  sl_wrdack <= sl_wrdack_x0;

  plbaddrpref_x0: entity work.plbaddrpref
    generic map (
      C_BASEADDR => C_BASEADDR,
      C_HIGHADDR => C_HIGHADDR,
      C_SPLB_DWIDTH => C_SPLB_DWIDTH,
      C_SPLB_NATIVE_DWIDTH => C_SPLB_NATIVE_DWIDTH
    )
    port map (
      plb_wrdbus => plbaddrpref_plb_wrdbus_net,
      sgsl_rddbus => plbaddrpref_sgsl_rddbus_net,
      addrpref => plbaddrpref_addrpref_net,
      sgplb_wrdbus => plbaddrpref_sgplb_wrdbus_net,
      sl_rddbus => plbaddrpref_sl_rddbus_net
    );

  sysgen_dut: entity work.w3_warplab_buffers_cw
    port map (
      agc_done => agc_done_x0,
      clk => clk,
      fromagc_radio1_i => fromagc_radio1_i_x0,
      fromagc_radio1_q => fromagc_radio1_q_x0,
      fromagc_radio2_i => fromagc_radio2_i_x0,
      fromagc_radio2_q => fromagc_radio2_q_x0,
      fromagc_radio3_i => fromagc_radio3_i_x0,
      fromagc_radio3_q => fromagc_radio3_q_x0,
      fromagc_radio4_i => fromagc_radio4_i_x0,
      fromagc_radio4_q => fromagc_radio4_q_x0,
      plb_abus => plb_abus_x0,
      plb_pavalid => plb_pavalid_x0,
      plb_rnw => plb_rnw_x0,
      plb_wrdbus => plbaddrpref_sgplb_wrdbus_net,
      radio1_adc_i => radio1_adc_i_x0,
      radio1_adc_q => radio1_adc_q_x0,
      radio1_rssi => radio1_rssi_x0,
      radio2_adc_i => radio2_adc_i_x0,
      radio2_adc_q => radio2_adc_q_x0,
      radio2_rssi => radio2_rssi_x0,
      radio3_adc_i => radio3_adc_i_x0,
      radio3_adc_q => radio3_adc_q_x0,
      radio3_rssi => radio3_rssi_x0,
      radio4_adc_i => radio4_adc_i_x0,
      radio4_adc_q => radio4_adc_q_x0,
      radio4_rssi => radio4_rssi_x0,
      sg_plb_addrpref => plbaddrpref_addrpref_net,
      splb_rst => splb_rst_x0,
      startcapture => startcapture_x0,
      starttx => starttx_x0,
      stoptx => stoptx_x0,
      xps_clk => xps_clk,
      debug_agc_done => debug_agc_done_x0,
      debug_capturing => debug_capturing_x0,
      debug_transmitting => debug_transmitting_x0,
      radio1_dac_i => radio1_dac_i_x0,
      radio1_dac_q => radio1_dac_q_x0,
      radio2_dac_i => radio2_dac_i_x0,
      radio2_dac_q => radio2_dac_q_x0,
      radio3_dac_i => radio3_dac_i_x0,
      radio3_dac_q => radio3_dac_q_x0,
      radio4_dac_i => radio4_dac_i_x0,
      radio4_dac_q => radio4_dac_q_x0,
      rssi_adc_clk => rssi_adc_clk_x0,
      sl_addrack => sl_addrack_x0,
      sl_rdcomp => sl_rdcomp_x0,
      sl_rddack => sl_rddack_x0,
      sl_rddbus => plbaddrpref_sgsl_rddbus_net,
      sl_wait => sl_wait_x0,
      sl_wrcomp => sl_wrcomp_x0,
      sl_wrdack => sl_wrdack_x0
    );

end structural;
